pub enum ProcessorError {
CommonError(String),
ForwardingError(String),
MessageExpiryCleanupError(String),
}Expand description
Errors relating to the Mediator Processors. These are largely internal to the Mediator errors They should not be exposed to the user
Variants
CommonError(String)
A general-purpose internal error in a background processor.
ForwardingError(String)
An error that occurred while forwarding a message to a remote mediator.
MessageExpiryCleanupError(String)
An error during the periodic cleanup of expired messages.